##  KPI Description and Calculation Logic
To view the KPI description and calculation logic, select a KPI on the dashboard, then click KPI Info in the overlay that appears. If applicable, you'll see a reference score for percentage points, which shows ranges for the KPI status, such as "On track," "Needs attention," or "Off track."
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiode3e6e4cfc584ecf94dbe7fd1ea1a415_LowRes.png)
KPI Description, Calculation Logic, and Reference Score
YesNo
Send
